<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About MystiQ</source>
        <translation>Acerca de MystiQ</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Translators</source>
        <translation>Traductores</translation>
    </message>
    <message>
        <source>Portable</source>
        <translation>Portable</translation>
    </message>
    <message>
        <source>Compiled with Qt %1</source>
        <translation>Compilado con Qt %1</translation>
    </message>
    <message>
        <source>Compiled with libnotify %1</source>
        <translation>Compilado con libnotify %1</translation>
    </message>
    <message>
        <source>MystiQ Homepage: %1</source>
        <translation>Sitio Web de MystiQ: %1</translation>
    </message>
    <message>
        <source>Some audio-processing functionalities are provided by SoX.</source>
        <translation>Algunas funcionalidades de procesamiento de audio son provistas por SoX.</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <extracomment>Spanish Language (Spain)</extracomment>
        <translation>Español (España)</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <source>MystiQ is a GUI frontend for FFmpeg.</source>
        <translation>MystiQ es una interfaz gráfica de usuario para FFmpeg.</translation>
    </message>
    <message>
        <source>Developers:&lt;br&gt; %1</source>
        <translation>Desarrolladores:&lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <extracomment>Swedish Language (Sweden)</extracomment>
        <translation>Sueco (Suecia)</translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <extracomment>Japanese Language (Japan)</extracomment>
        <translation>Japonés (Japón)</translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <extracomment>German Language (Germany)</extracomment>
        <translation>Alemán (Alemania)</translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <extracomment>Italian Language (Italy)</extracomment>
        <translation>Italiano (Italia)</translation>
    </message>
    <message>
        <source>Application Name:&lt;br&gt; %1</source>
        <translation>Nombre de la Aplicación:&lt;br&gt; %1</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License version 3.</source>
        <translation>Este programa es software libre; puede redistribuirlo y / o modificarlo bajo los términos de la GNU General Public License versión 3.</translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <extracomment>Turkish Language (Turkey)</extracomment>
        <translation>Turco (Turquía)</translation>
    </message>
    <message>
        <source>Many people have contributed translations. You can also help translate the MystiQ Video Converter into your own language. Visit </source>
        <translation>Muchas personas han contribuido con traducciones. También puede ayudar a traducir MystiQ Video Converter a su propio idioma. Visitar </translation>
    </message>
    <message>
        <source> and join a translation team.</source>
        <translation> y únete a un equipo de traducción.</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation>Cambios</translation>
    </message>
    <message>
        <source>Hungarian (Hungary)</source>
        <extracomment>Hungarian Language (Hungary)</extracomment>
        <translation>Húngaro (Hungría)</translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <extracomment>Russian Language (Russia)</extracomment>
        <translation>Ruso (Rusia)</translation>
    </message>
    <message>
        <source>Collaborators:&lt;br&gt; %1</source>
        <translation>Colaboradores:&lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Some features of MystiQ Video Converter have been inspired by</source>
        <translation>Algunas características de MystiQ Video Converter se han inspirado en</translation>
    </message>
    <message>
        <source>Galician (Galicia)</source>
        <extracomment>Galician Language (Galicia)</extracomment>
        <translatorcomment>Idioma Gallego (Galicia)</translatorcomment>
        <translation>Gallego (Galicia)</translation>
    </message>
    <message>
        <source>Icons Theme:&lt;br&gt; %1</source>
        <translation>Tema de Iconos:&lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Indonesian (Indonesia)</source>
        <extracomment>Indonesian Language (Indonesia)</extracomment>
        <translatorcomment>Idioma Indonesio (Indonesia)</translatorcomment>
        <translation>Indonesio (Indonesia)</translation>
    </message>
</context>
<context>
    <name>AboutFFmpegDialog</name>
    <message>
        <source>About FFmpeg</source>
        <translation>Acerca de FFmpeg</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Available Codecs</source>
        <translation>Códecs Disponibles</translation>
    </message>
    <message>
        <source>FFmpeg is a complete, cross-platform solution to record, convert and stream audio and video. It includes libavcodec - the leading audio/video codec library.</source>
        <extracomment>ffmpeg description</extracomment>
        <translation>FFmpeg es una completa solución multi-plataforma para grabar, convertir y transmitir audio y video. incluye libavcodec - la libreria lider de audio/video.</translation>
    </message>
    <message>
        <source>FFmpeg is free software licensed under the LGPL or GPL.</source>
        <translation>FFmpeg es software libre bajo licencia LGPL o GPL.</translation>
    </message>
    <message>
        <source>Please visit %1 for more information.</source>
        <translation>Por favor visite %1 para más información.</translation>
    </message>
</context>
<context>
    <name>AddTaskWizard</name>
    <message>
        <source>Add Tasks</source>
        <translation>Agregar tareas</translation>
    </message>
    <message>
        <source>Files to be converted</source>
        <translation>Archivos a ser convertidos</translation>
    </message>
    <message>
        <source>Add files.</source>
        <translation>Agregar Archivos.</translation>
    </message>
    <message>
        <source>Remove selected files.</source>
        <translation>Remover archivos seleccionados.</translation>
    </message>
    <message>
        <source>Output Settings</source>
        <translation>Configuración de salida</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Auto adjust output bitrate to reduce output file size.</source>
        <translation>Auto ajustar el bitrate de salida para reducir el tamaño de archivo de salida.</translation>
    </message>
    <message>
        <source>Auto Adjust Audio Bitrate</source>
        <translation>Auto ajustar el bitrate del audio</translation>
    </message>
    <message>
        <source>Preset</source>
        <translation>Preconfiguración</translation>
    </message>
    <message>
        <source>Convert to</source>
        <translation>Convertir a</translation>
    </message>
    <message>
        <source>Output Path</source>
        <translation>Directorio de salida</translation>
    </message>
    <message>
        <source>Select &amp;folder</source>
        <translation>Seleccionar &amp;Carpeta</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Explorar</translation>
    </message>
    <message>
        <source>Create &amp;new folder in source folder</source>
        <extracomment>Create a new folder (e.g. mystiq_output) in the folder containing the input files. Put the output files in the newly created folder.</extracomment>
        <translation>Crear una nueva Carpe&amp;ta en la Carpeta de Origen</translation>
    </message>
    <message>
        <source>Folder Name</source>
        <translation>Nombre de la carpeta</translation>
    </message>
    <message>
        <source>Output to &amp;source folder</source>
        <extracomment>put the output files in the same folder as the input files</extracomment>
        <translation>Salida a la &amp;carpeta de origen</translation>
    </message>
    <message>
        <source>Please select at least one file.</source>
        <translation>Por favor seleccione al menos un archivo.</translation>
    </message>
    <message>
        <source>Select Files</source>
        <extracomment>This text is the title of an openfile dialog.</extracomment>
        <translation>Seleccione archivos</translation>
    </message>
    <message>
        <source>Multimedia</source>
        <translation>Multimedia</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Todos los archivos</translation>
    </message>
    <message>
        <source>Select Directory</source>
        <extracomment>This text is the title of an open directory dialog.</extracomment>
        <translation>Seleccione un directorio</translation>
    </message>
    <message>
        <source>Searching for files...</source>
        <translation>Buscando archivos...</translation>
    </message>
    <message>
        <source>Some files could not be found.</source>
        <translation>Algunos archivos no pudieron ser encontrados.</translation>
    </message>
    <message>
        <source>Folder does not exist. Create a new folder?</source>
        <translation>La carpeta no existe. ¿Crear una nueva carpeta?</translation>
    </message>
    <message>
        <source>Failed to create folder. Please select another output folder.</source>
        <translation>Falló al crear la carpeta. Por favor seleccione otra carpeta de salida.</translation>
    </message>
    <message>
        <source>Add Files</source>
        <translation>Añadir archivos</translation>
    </message>
    <message>
        <source>Remove Selected</source>
        <translation>Eliminar Seleccionados</translation>
    </message>
    <message>
        <source>Clear List</source>
        <translation>Limpiar Lista</translation>
    </message>
</context>
<context>
    <name>ConversionParameterDialog</name>
    <message>
        <source>Conversion Parameters</source>
        <translation>Parámetros de Conversión</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Disable Audio</source>
        <translation>Deshabilitar Audio</translation>
    </message>
    <message>
        <source>Audio Options</source>
        <translation>Opciones de Audio</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation>Tasa de muestreo</translation>
    </message>
    <message>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <source>Bitrate</source>
        <translation>Bitrate</translation>
    </message>
    <message>
        <source>(auto)</source>
        <translation>(auto)</translation>
    </message>
    <message>
        <source>kb/s</source>
        <translation>kb/s</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Canales</translation>
    </message>
    <message>
        <source>Volume</source>
        <translation>Volumen</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Disable Video</source>
        <translation>Deshabilitar Video</translation>
    </message>
    <message>
        <source>Video Options</source>
        <translation>Opciones de Video</translation>
    </message>
    <message>
        <source>Same Quantizer as Source</source>
        <translation>Mismo cuantificador que la fuente</translation>
    </message>
    <message>
        <source>Deinterlace</source>
        <translation>Desentrelazar</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Ancho</translation>
    </message>
    <message>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Altura</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Recortar</translation>
    </message>
    <message>
        <source>Time</source>
        <extracomment>time-related options (speed, length)</extracomment>
        <translation>Tiempo</translation>
    </message>
    <message>
        <source>Cutting</source>
        <extracomment>video time cutting: options for begin time and end time</extracomment>
        <translation>Cortando</translation>
    </message>
    <message>
        <source>Cut</source>
        <comment>Cut video; select a range to convert</comment>
        <translation>Cortar</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Previsualizar</translation>
    </message>
    <message>
        <source>Scaling</source>
        <extracomment>time scaling, changing the speed of the output file</extracomment>
        <translation>Escalado</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidad</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avanzado</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Additional FFmpeg Options</source>
        <translation>Opciones Adicionales de FFmpeg</translation>
    </message>
    <message>
        <source>Copy Audio (Do not re-encode)</source>
        <translation>Copiar Audio (No Recodificar)</translation>
    </message>
    <message>
        <source>Insert Subtitle if Available</source>
        <translation>Insertar Subtítulo si está disponible</translation>
    </message>
    <message>
        <source>Copy Video (Do not re-encode)</source>
        <translation>Copiar Video (No recodificar)</translation>
    </message>
    <message>
        <source>qrc:/qml/main.qml</source>
        <translation>qrc:/qml/main.qml</translation>
    </message>
    <message>
        <source>Video Extra Options</source>
        <translation>Opciones Extras de Vídeo</translation>
    </message>
    <message>
        <source>Video to Black and White</source>
        <translation>Vídeo a Blanco y Negro</translation>
    </message>
    <message>
        <source>Vertical Flip</source>
        <translation>Volteo vertical</translation>
    </message>
    <message>
        <source>Horizontal Flip</source>
        <translation>Volteo horizontal</translation>
    </message>
    <message>
        <source>Rotate 90 degrees clockwise</source>
        <translation>Girar 90 grados en sentido horario</translation>
    </message>
    <message>
        <source>Rotate 90 degrees counterclockwise</source>
        <translation>Girar 90 grados en sentido antihorario</translation>
    </message>
    <message>
        <source>Rotate 180 degrees</source>
        <translation>Girar 180 grados</translation>
    </message>
    <message>
        <source>3D Options</source>
        <translation>Opciones 3D</translation>
    </message>
    <message>
        <source>Red Blue Gray Monochromatic</source>
        <translation>Rojo Azul Gris Monocromático</translation>
    </message>
    <message>
        <source>Red Cyan Dubois</source>
        <translation>Rojo Cyan Madera</translation>
    </message>
    <message>
        <source>Green Magenta Color</source>
        <translation>Verde Magenta Color</translation>
    </message>
    <message>
        <source>Red Cyan Half Color</source>
        <translation>Rojo Cyan Semi-Color</translation>
    </message>
    <message>
        <source>Yellow Blue Color</source>
        <translation>Amarillo Azul Color</translation>
    </message>
    <message>
        <source>Red Cyan Color</source>
        <translation>Rojo Cyan Color</translation>
    </message>
    <message>
        <source>Green Magenta Gray Monochromatic</source>
        <translation>Verde Magenta Gris Monocromático</translation>
    </message>
    <message>
        <source>Red Green Gray Monochromatic</source>
        <translation>Rojo Verde Gris Monocromático</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Sin efecto 3D</translation>
    </message>
</context>
<context>
    <name>ConvertList</name>
    <message>
        <source>Cancel</source>
        <extracomment>Cancel the operation of adding new tasks</extracomment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Adding files (%1/%2)</source>
        <extracomment>This text is the progress indicator of adding multiple tasks. %1 is the number of files that are already added. %2 is the total number of files.</extracomment>
        <translation>Añadiendo archivos (%1/%2)</translation>
    </message>
    <message>
        <source>Some files are not recognized by the converter.</source>
        <translation>Algunos archivos no son reconocidos por el convertidor.</translation>
    </message>
    <message>
        <source>New File Name</source>
        <translation>Nuevo Nombre de Archivo</translation>
    </message>
    <message>
        <source>Please input the new name for the output file.</source>
        <translation>Por favor ingrese el nuevo nombre para el archivo de salida.</translation>
    </message>
    <message>
        <source>Output Directory</source>
        <translation>Directorio de Salida</translation>
    </message>
    <message>
        <source>Error Message from FFmpeg:

</source>
        <translation>Mensage de error de FFmpeg:

</translation>
    </message>
    <message>
        <source>Drag and drop files here to add tasks.</source>
        <translation>Arrastre y suelte los archivos aquí para añadir tareas.</translation>
    </message>
    <message>
        <source>Hide &quot;%1&quot;</source>
        <extracomment>Hide a column in the list. For example, the text maybe &apos;Hide &quot;Duration&quot;&apos;. The two &quot; are quotation marks in English, you may replace it with local quotation marks.</extracomment>
        <translation>Ocultar &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Restore All Columns</source>
        <translation>Restaurar todas las columnas</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>Destino</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation>Tamaño del archivo</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <extracomment>Audio</extracomment>
        <translation>Tasa de muestreo</translation>
    </message>
    <message>
        <source>Audio Bitrate</source>
        <translation>Tasa de bits de audio</translation>
    </message>
    <message>
        <source>Channels</source>
        <extracomment>Audio</extracomment>
        <translation>Canales</translation>
    </message>
    <message>
        <source>Audio Codec</source>
        <translation>Códec de Audio</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensiones</translation>
    </message>
    <message>
        <source>Video Bitrate</source>
        <translation>Tasa de bits de vídeo</translation>
    </message>
    <message>
        <source>Framerate</source>
        <extracomment>Video</extracomment>
        <translation>Tasa de fotogramas</translation>
    </message>
    <message>
        <source>Video Codec</source>
        <translation>Códec de Video</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Progreso</translation>
    </message>
    <message>
        <source>%1 Hz</source>
        <translation>%1 Hz</translation>
    </message>
    <message>
        <source>%1 kb/s</source>
        <translation>%1 kb/s</translation>
    </message>
    <message>
        <source>%1 fps</source>
        <translation>%1 fps</translation>
    </message>
    <message>
        <source>Removing tasks...</source>
        <extracomment>Remove files from the tasklist</extracomment>
        <translation>Removiendo tareas...</translation>
    </message>
    <message>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <source>B</source>
        <extracomment>Bytes</extracomment>
        <translation>B</translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation>El archivo existe</translation>
    </message>
    <message>
        <source>%1 already exists on disk or in the task list. Still use this name as the output filename?</source>
        <translation>%1 ya existe en el disco o en la lista de tareas. ¿Aún así utilizará este nombre como nombre de archivo de salida?</translation>
    </message>
    <message>
        <source>Remove Task</source>
        <translation>Remover Tarea</translation>
    </message>
    <message>
        <source>Cannot remove a task while it is in progress.</source>
        <translation>No puede remover un tarea mientras está en progreso.</translation>
    </message>
    <message>
        <source>Finished</source>
        <extracomment>The text to be displayed on the progress bar when a conversion finishes</extracomment>
        <translation>Terminado</translation>
    </message>
    <message>
        <source>Failed</source>
        <extracomment>The text to be displayed on the progress bar when a conversion fails</extracomment>
        <translation>Falló</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <extracomment>%1 is the error message</extracomment>
        <translation>Error: %1</translation>
    </message>
</context>
<context>
    <name>ExtraTranslations</name>
    <message>
        <source>Convert between media file formats</source>
        <translation>Convertir entre formados de archivos</translation>
    </message>
    <message>
        <source>Media Converter</source>
        <translation>Convertidor de Medios</translation>
    </message>
</context>
<context>
    <name>HelpMystiQDialog</name>
    <message>
        <source>User Manual</source>
        <translation>Manual de Usuario</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Fira Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:18pt; font-weight:600;&quot;&gt;MystiQ User&apos;s Manual&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/mystiq_96x96.png&quot; style=&quot;float: left;&quot; /&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter is a cross platform application. This application has as its sole objective the conversion of audio and video files to multiple formats. As a distinctive feature, MystiQ is an open source project, which means that the source code will always be available and everyone who wishes to contribute to the development is welcome.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter is free: you can redistribute it and / or modify it under the terms GNU (General Public License) published by the Free Software Foundation. MystiQ Video Converter is freely distributed with the sole purpose of being a useful application to your needs, but WITHOUT NO WARRANTY, even if its use is COMMERCIAL or MERELY A PARTICULAR PURPOSE See the GPL v3 license for more details. This application includes an English copy of the Software distribution license.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;The essential idea of ​​the development team is to provide a friendly and simple user interface. The simple is the essence of MystiQ, which means that it is not our objective to add features that complicate the operation of the application.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Currently MystiQ is mainly developed in C ++ taking advantage of the Qt5 graphic libraries. In the FFmpeg backend he is in charge of converting between formats, so we can say that MystiQ is simply a graphical interface for FFmpeg.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ currently allows you to convert to most existing video formats, as well as make it possible to extract audio and convert between audio formats. It also includes a small tool to trim videos based on the duration of these.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter currently supports the following audio and video formats:&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Audio: mp3 m4a 3g2 ogg wav wma  ac3 ra ape flac opus&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Video: avi vfw divx mpg mpeg m1v m2v mpv dv 3gp mov mp4 m4v mqv dat vcd ogg ogm ogv asf wmv bin iso vob mkv nsv ram flv rm swf ts rmvb dvr-ms m2t m2ts rec mts webm dv&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot1.png&quot; /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Toolbar&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;In the upper part of the main window of the application we will find the toolbar with the following buttons:&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot2.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;ul style=&quot;margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;&quot;&gt;&lt;li style=&quot;&quot; style=&quot; margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Add Files:&lt;/span&gt; &lt;span style=&quot; font-size:12pt;&quot;&gt;Opens a dialog to select the video files you want to convert. Once selected, they are placed in the List of Conversion Tasks&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Start: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Start conversion process from the list of loaded items&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Stop: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Stops the process of converting an item&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Retry:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Retry the process of converting an item&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Retry All:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Retry the conversion process of all items in the list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Remove Selected:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove a selected item from the list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Remove Completed:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove all items from the list that have completed the conversion process&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Clear List:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove all items from the conversion list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Open Output Folder: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;From the system file manager open the folder that contains the converted files&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot; font-size:12pt;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Power Options:&lt;/span&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;  &lt;/span&gt;Choose whether to shut down, suspend or hibernate the computer when completing the conversion process of all items in the list&lt;/li&gt;&lt;/ul&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Audio Options&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot3.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Disable Audio:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to obtain a resulting file excluding sound.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Copy audio (do not recode):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to convert without processing the audio from the source file. The resulting file will have the same sound parameters as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Sample Rate:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; In audio production, a sample rate (or &amp;quot;sampling rate&amp;quot;) defines how many times per second a sound is sampled. Technically speaking, it is the frequency of samples used in a digital recording.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Bitrate:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; It&apos;s the bit rate or data that is processed per unit of time. The average bitrate for an MP3 file is 128 kbits per second or kbps.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Channels: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s the passage way a signal or data is transported. In case of audio files, it&apos;s the passage or communication channel in which a sound signal is transported from the player source to the speaker. An audio file can contain one, two or even more Channels.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Volume: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Allows you to configure the maximum volume of the destination file taking as a match the volume level of the source file.&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Video Options&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot4.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Insert Subtitle if Available: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;By checking this option, the application will verify if a subtitle file of the same name is found in the same location of the source file, if found, it will embed it in the resulting file. It is currently compatible with subtitles in SRT, SSA, ASS and SUB format.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Disable Video:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to obtain a resulting file excluding video.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Copy Video (Do not re-encode):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to convert without processing the video from the source file. The resulting file will have the same video parameters as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Video to Black and White: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It allows to obtain a video file is grayscale.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Flip and Rotate options: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;The resulting file will be rotated or flipped in the direction chosen.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Deinterlace: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s the process of converting interlaced video, such as common analog television signals or 1080i format HDTV signals, into a non-interlaced form. An interlaced video frame consists of two sub-fields taken in sequence, each sequentially scanned at odd, and then even, lines of the image sensor.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Same Quantizer as source: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s involved in image processing, is a lossy compression technique achieved by compressing a range of values to a single quantum value. Checking this option the resulting file will have the same deinterlacing as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>InteractiveCuttingDialog</name>
    <message>
        <source>Cutting</source>
        <comment>Cutting as in &quot;cutting video&quot;</comment>
        <translation>Cortando</translation>
    </message>
    <message>
        <source>Mark as Begin</source>
        <translation>Marcar como Inicio</translation>
    </message>
    <message>
        <source>Seek to Begin</source>
        <translation>Buscar al Inicio</translation>
    </message>
    <message>
        <source>Play Selection</source>
        <translation>Reproducir Selección</translation>
    </message>
    <message>
        <source>Mark as End</source>
        <translation>Marcar como Fin</translation>
    </message>
    <message>
        <source>Seek to End</source>
        <translation>Buscar al Final</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Start conversion process.</source>
        <translation>Iniciar Proceso de Conversión.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <source>&amp;Convert</source>
        <translation>&amp;Convertir</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Add Files</source>
        <translation>&amp;Añadir Archivos</translation>
    </message>
    <message>
        <source>Add files for conversion.</source>
        <translation>Añadir archivos para conversión.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>Exit the program.</source>
        <translation>Salir de la Aplicación.</translation>
    </message>
    <message>
        <source>S&amp;top</source>
        <translation>&amp;Detener</translation>
    </message>
    <message>
        <source>Stop conversion process.</source>
        <translation>Detener proceso de conversión.</translation>
    </message>
    <message>
        <source>Set &amp;Parameters</source>
        <translation>Configurar &amp;Parámetros</translation>
    </message>
    <message>
        <source>Set Parameters</source>
        <extracomment>Edit output file parameters.</extracomment>
        <translation>Configurar parámetros</translation>
    </message>
    <message>
        <source>Edit conversion parameters of selected files.</source>
        <translation>Editar parámetros de conversión de los archivos seleccionados.</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Acerca de Qt</translation>
    </message>
    <message>
        <source>&amp;Open Output Folder</source>
        <translation>&amp;Abrir Carpeta de Salida</translation>
    </message>
    <message>
        <source>Open output folder of the selected file.</source>
        <translation>Abrir carpeta de salida del archivo seleccionado.</translation>
    </message>
    <message>
        <source>About &amp;FFmpeg</source>
        <translation>Acerca de &amp;FFmpeg</translation>
    </message>
    <message>
        <source>About FFmpeg</source>
        <translation>Acerca de FFmpeg</translation>
    </message>
    <message>
        <source>&amp;Remove Selected</source>
        <extracomment>remove selected (tasks, items)</extracomment>
        <translation>&amp;Borrar Seleccionado</translation>
    </message>
    <message>
        <source>Remove all selected items in the list.</source>
        <translation>Borrar todos los objetos seleccionados en la lista.</translation>
    </message>
    <message>
        <source>R&amp;emove Completed</source>
        <extracomment>remove completed (task, items)</extracomment>
        <translation>B&amp;orrar Completado</translation>
    </message>
    <message>
        <source>Remove Completed Items</source>
        <translation>Borrar objetos completados</translation>
    </message>
    <message>
        <source>Remove all completed items in the list.</source>
        <translation>Quitar todos los elementos completados de la lista.</translation>
    </message>
    <message>
        <source>Clear List</source>
        <translation>Limpiar Lista</translation>
    </message>
    <message>
        <source>Remove all items in the list.</source>
        <translation>Borrar todos los elementos en la lista.</translation>
    </message>
    <message>
        <source>&amp;Retry</source>
        <translation>&amp;Reintentar</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Reintentar</translation>
    </message>
    <message>
        <source>Retry selected tasks.</source>
        <translation>Reintentar todas las tareas.</translation>
    </message>
    <message>
        <source>Retry &amp;All</source>
        <translation>Reintentar &amp;Todo</translation>
    </message>
    <message>
        <source>Retry all tasks.</source>
        <translation>Reintentar todas las tareas.</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Opciones</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>About This Program</source>
        <translation>Acerca de esta Aplicación</translation>
    </message>
    <message>
        <source>Change Output &amp;Filename</source>
        <translation>&amp;Cambiar el nombre del archivo de salida</translation>
    </message>
    <message>
        <source>Change the output filename of the selected item.</source>
        <translation>Cambiar el nombre de salida de los archivos seleccionados.</translation>
    </message>
    <message>
        <source>Change Output &amp;Directory</source>
        <translation>Cambiar el directorio de &amp;salida</translation>
    </message>
    <message>
        <source>Change the output directory of the selected items.</source>
        <translation>Cambiar el directorio de salida de los archivos seleccionados.</translation>
    </message>
    <message>
        <source>Show Error &amp;Message</source>
        <translation>&amp;Mostrar mensaje de error</translation>
    </message>
    <message>
        <source>Check For &amp;Updates</source>
        <translation>Buscar &amp;actualizaciones</translation>
    </message>
    <message>
        <source>Cut</source>
        <extracomment>Cut video file (select a time range to conert)</extracomment>
        <translation>Cortar</translation>
    </message>
    <message>
        <source>All tasks have finished.</source>
        <translation>Todas las tareas han sido finalizadas.</translation>
    </message>
    <message>
        <source>Nothing to convert.</source>
        <translation>Nada que convertir.</translation>
    </message>
    <message>
        <source>Conversion is still in progress. Abort?</source>
        <translation>Conversión aún en progreso. ¿Abortar?</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <extracomment>Shutdown the computer (completely poweroff)</extracomment>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Shutdown when all tasks are done.</source>
        <translation>Apagar cuando todas las tareas sean terminadas.</translation>
    </message>
    <message>
        <source>Suspend</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Suspend when all tasks are done.</source>
        <translation>Suspender cuando todas las tareas sean terminadas.</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Hibernate when all tasks are done.</source>
        <translation>Hibernar cuando todas las tareas sean terminadas.</translation>
    </message>
    <message>
        <source>This program is going to check for updates online. Do you allow this program to use the Internet to check for updates?</source>
        <translation>Este programa va a comprobar si hay actualizaciones en línea. ¿Quieres permitir que este programa se conecte a Internet para buscar actualizaciones?</translation>
    </message>
    <message>
        <source>Failed to load preset file. The application will quit now.</source>
        <translation>Falló al cargar la preconfiguración. La aplicación se cerrará ahora.</translation>
    </message>
    <message>
        <source>Elapsed Time: %1 h %2 m %3 s</source>
        <translation>Tiempo estimado: %1 h %2 m %3 s</translation>
    </message>
    <message>
        <source>MystiQ Media Converter</source>
        <translation>MystiQ Media Converter</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>Clear &amp;List</source>
        <translation>Limpiar &amp;Lista</translation>
    </message>
    <message>
        <source>About MystiQ</source>
        <translation>Acerca de MystiQ</translation>
    </message>
    <message>
        <source>Poweroff</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>User Manual</source>
        <translation>Manual de Usuario</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>&amp;Report Error</source>
        <translation>&amp;Reportar Error</translation>
    </message>
    <message>
        <source>Report Error</source>
        <translation>Reportar Error</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
    <message>
        <source>Conversion failed.</source>
        <translation>Conversión fallida.</translation>
    </message>
    <message>
        <source>Support MystiQ</source>
        <translation>Ayuda a mantener MystiQ</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>MystiQ needs you</source>
        <translation>MystiQ te necesita</translation>
    </message>
    <message>
        <source>MystiQ is free software. However the development requires a lot of time and a lot of work. In order to keep developing MystiQ with new features we need your help. Please consider to support the MystiQ project by sending a donation. &lt;b&gt;Even the smallest amount will help a lot.&lt;/b&gt;</source>
        <translation>MystiQ es software libre. Sin embargo, el desarrollo requiere mucho tiempo y mucho trabajo. Para seguir desarrollando MystiQ con nuevas características, necesitamos su ayuda. Por favor considere apoyar el proyecto MystiQ enviando una donación. &lt;b&gt; Incluso la cantidad más pequeña ayudará mucho. &lt;/b&gt;</translation>
    </message>
    <message>
        <source>Reporting bugs from MystiQ </source>
        <translation>Reportando fallos desde MystiQ </translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Your comment:</source>
        <translation>Un comentario:</translation>
    </message>
    <message>
        <source>Report:</source>
        <translation>Reportar el error:</translation>
    </message>
    <message>
        <source>MystiQ is Converting %1/%2</source>
        <extracomment>Converting the %1-th file in %2 files. %2 is the number of files.</extracomment>
        <translation>MystiQ está Convirtiendo %1/%2</translation>
    </message>
    <message>
        <source>MystiQ Video Converter</source>
        <translation>MystiQ Video Converter</translation>
    </message>
    <message>
        <source>Conversion finished successfully.</source>
        <translation>Conversión finalizada exitosamente.</translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>Traducir</translation>
    </message>
    <message>
        <source>Translate Application</source>
        <translation>Traducir Aplicación</translation>
    </message>
    <message>
        <source>Report Bugs</source>
        <translation>Reportar Errores</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>We need your feedback</source>
        <translation>Necesitamos sus reportes</translation>
    </message>
    <message>
        <source>Github</source>
        <translation>Github</translation>
    </message>
    <message>
        <source>MystiQ Video Converter development team needs users who use the application to help detect errors. If you find an error and report it to our team, it will help speed up the correction process. Therefore, you can be part of our development team even if you are not a developer. To report an error, you can send us an email with the detailed description of it or you can enter Github and describe the issue (in this case you must have a GitHub Account).</source>
        <translation>El equipo de desarrollo de MystiQ Video Converter necesita que los usuarios que usan la aplicación ayuden a la detección de errores. Si usted detecta algún error y lo informa a nuestro equipo, ayudará a acelerar el proceso de corrección. Por lo tanto, puede ser parte de nuestro equipo de desarrollo incluso si no es un programador. Para informar errores, puede enviarnos un correo electrónico con la descripción detallada del mismo o puede ingresar a Github y describirnos el problema (en este caso debe tener creada una cuenta en Github).</translation>
    </message>
    <message>
        <source>Gitter</source>
        <translation>Gitter</translation>
    </message>
</context>
<context>
    <name>MediaConverter</name>
    <message>
        <source> FFmpeg or FFprobe %1 have not been found in the system. Please consider installing them before running MystiQ</source>
        <extracomment>%1 is a computer program</extracomment>
        <translation> FFmpeg o FFprobe %1 no se han encontrado en el sistema. Por favor considere instalarlos antes de ejecutar MystiQ</translation>
    </message>
</context>
<context>
    <name>MediaPlayerWidget</name>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Check for updates on program startup</source>
        <translation>Chequear actualizaciones al iniciar la aplicación</translation>
    </message>
    <message>
        <source>Automatically start conversion after adding files to the list.</source>
        <translation>Iniciar automáticamente la conversión después de añadir archivos a la lista.</translation>
    </message>
    <message>
        <source>Start conversion automatically</source>
        <translation>Iniciar conversión automáticamente</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Number of threads to use in conversion</source>
        <translation>Numero de procesos a usar en la conversión</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Hide output formats that are not available in the current ffmpeg installation. It is recommended to turn this option on unless you are sure that MystiQ has failed to detect available formats. (requires restarting MystiQ to take effect)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ocultar formatos de salida que no están disponibles en la actual instalación de FFmpeg. Es recomendable activar esta opción hasta que esté seguro que MystiQ ha fallado en detectar los formatos disponibles. (Se necesita reiniciar MystiQ para que la configuración tome efecto)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Hide unavailable formats (requires restarting)</source>
        <translation>Ocultar formatos no disponibles (Requiere reiniciar)</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Herrramientas</translation>
    </message>
    <message>
        <source>You have to restart MystiQ for the changes to take effect.</source>
        <translation>Usted debe reiniciar MystiQ para que los cambios tomen efecto.</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
</context>
<context>
    <name>PoweroffDialog</name>
    <message>
        <source>MystiQ</source>
        <translation>MystiQ</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Shutdown immediately</source>
        <extracomment>Shutdown the computer</extracomment>
        <translation>Apagar inmediatamente</translation>
    </message>
    <message>
        <source>Suspend immediately</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Suspender inmediatamente</translation>
    </message>
    <message>
        <source>Hibernate immediately</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Hibernar inmediatamente</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <extracomment>Shutdown the computer</extracomment>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Operation Failed: %1</source>
        <translation>Operación fallida: %1</translation>
    </message>
    <message>
        <source>Shutting down in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>Apagar en &lt;b&gt;%1&lt;/b&gt; segundos</translation>
    </message>
    <message>
        <source>Suspending in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>Suspender en &lt;b&gt;%1&lt;/b&gt; segundos</translation>
    </message>
    <message>
        <source>Hibernating in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>Hibernar en &lt;b&gt;%1&lt;/b&gt; segundos</translation>
    </message>
</context>
<context>
    <name>PreviewDialog</name>
    <message>
        <source>Play Selected Range</source>
        <translation>Reproducir Rango Seleccionado</translation>
    </message>
    <message>
        <source>Begin</source>
        <extracomment>noun, the beginning of the video</extracomment>
        <translation>Inicio</translation>
    </message>
    <message>
        <source>End</source>
        <extracomment>noun, the end of the video</extracomment>
        <translation>Final</translation>
    </message>
    <message>
        <source>Play %1~%2</source>
        <extracomment>play the video from time %1 to time %2. %1 and %2 are time in hh:mm:ss format.</extracomment>
        <translation>Reprodución %1~%2</translation>
    </message>
    <message>
        <source>Video Preview</source>
        <translation>Vista Previa del Vídeo</translation>
    </message>
</context>
<context>
    <name>TimeRangeEdit</name>
    <message>
        <source>From Begin</source>
        <translation>Desde el Inicio</translation>
    </message>
    <message>
        <source>To End</source>
        <translation>Al Final</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Show &amp;Release Notes</source>
        <translation>Mostrar &amp;Notas de Liberación</translation>
    </message>
    <message>
        <source>Check for updates on program startup</source>
        <translation>Chequear actualizaciones al iniciar la aplicación</translation>
    </message>
    <message>
        <source>Downloading update information...</source>
        <translation>Descargando información de actualización...</translation>
    </message>
    <message>
        <source>Cannot connect to server.</source>
        <translation>Imposible conectar al servidor.</translation>
    </message>
    <message>
        <source>Failed to parse the received data.</source>
        <translation>Error al analizar los datos recibidos.</translation>
    </message>
    <message>
        <source>You are already using the latest version of MystiQ.</source>
        <translation>Ya está usando la versión mas reciente de MystiQ.</translation>
    </message>
    <message>
        <source>An unknown error has occurred.</source>
        <translation>Un error desconocido ha ocurrido.</translation>
    </message>
    <message>
        <source>A new version of MystiQ has been released!</source>
        <translation>¡Una nueva versión de MystiQ ha sido liberada!</translation>
    </message>
    <message>
        <source>Version &lt;b&gt;%1&lt;/b&gt; is available at %2.</source>
        <extracomment>%1 is version number, %2 is the project homepage</extracomment>
        <translation>La versión &lt;b&gt;%1&lt;/b&gt; está disponible en %2.</translation>
    </message>
    <message>
        <source>You can download this version using the link:</source>
        <translation>Puede descargar esta versión usando el enlace:</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Chequear Actualizaciones</translation>
    </message>
    <message>
        <source>The current version you are using is newer than the release channel version.&lt;br&gt;Therefore, you are using the development channel.</source>
        <translation>La actual versión que estás usando es más reciente que la versión del canal de liberación.&lt;br&gt;Por lo tanto, estás usando el canal de desarrollo.</translation>
    </message>
</context>
</TS>
